@@ -98,15 +98,20 @@ sub iter_cidr {
     if (wantarray) {
       my @items;
       while (my @cidr = Net::Silk::IPWildcard::iter_xs::next_cidr($iter)) {
-        push(@items, \@cidr);
+        push(@items, SILK_CIDR_CLASS->new(@cidr));
       }
       return @items;
     }
     my @res = Net::Silk::IPWildcard::iter_xs::next_cidr($iter);
-    @res ? \@res : ();
+    @res ? SILK_CIDR_CLASS->new(@res) : ();
   };
 }
 
+sub iter_ranges {
+  my $self = shift;
+  SILK_CIDR_CLASS->_iter_ranges($self->iter_cidr);
+}
+
 sub iter_bag {
   my $self = shift;
   my $iter = Net::Silk::IPWildcard::iter_xs->bind($self);
@@ -224,9 +229,13 @@ by this wildcard. In list context this will slurp all addresses.
 
 =item iter_cidr()
 
-Return a sub ref iterator that returns an array ref containing
-the L<Net::Silk::IPAddr> and CIDR prefix for each CIDR block contained
-in this wildcard.
+Return a sub ref iterator that returns a L<Net::Silk::CIDR> object for
+each CIDR block contained in this wildcard.
+
+=item iter_ranges()
+
+Return a sub ref iterator that returns a L<Net::Silk::Range> object for
+each IP range contained in this wildcard.
 
 =back
 
