@@ -48,7 +48,7 @@ use strict;
 use warnings;
 use Carp;
 
-use vars qw( @EXPORT_OK %EXPORT_TAGS @ALL );
+use vars qw( @EXPORT_OK %EXPORT_TAGS );
 
 use base qw(Exporter);
 
@@ -58,7 +58,7 @@ use Math::Int64 qw( uint64 );
 
 our $INITIALIZED     = 0;
 our $SITE_CONFIGURED = 0;
-our $HAVE_SITE       = 0;
+our $SITE_CONFIG_OK  = 0;
 
 our %SENSORS_BY_ID;
 our %CLASSES_BY_ID;
@@ -69,12 +69,13 @@ our %CLASSES;
 our %FLOWTYPES;
 our %CLASSTYPES;
 
-our $DEFAULT_CLASS;
-
 sub init_maps {
-  if ($INITIALIZED || !($HAVE_SITE || load_site())) {
-    return $INITIALIZED;
-  }
+  return 1 if $INITIALIZED;
+  load_site();
+  return 0 unless $SITE_CONFIG_OK;
+  %SENSORS_BY_ID   = _sensors_by_id();
+  %CLASSES_BY_ID   = _classes_by_id();
+  %FLOWTYPES_BY_ID = _flowtypes_by_id();
   for my $id (keys %SENSORS_BY_ID) {
     my $id_desc = $SENSORS_BY_ID{$id};
     my $desc = $SENSORS{$id_desc->{name}} = {%$id_desc};
@@ -113,60 +114,70 @@ sub init_maps {
 }
 
 sub init_site {
+  # this only runs if invoked manually by the user since it sets
+  # values subsequently used by the silk library in load_site();
+  # otherwise the defaults are used (from env vars, etc)
   my %kv = @_;
   my $site_conf = $kv{siteconf};
   my $root_dir  = $kv{rootdir};
 
   if ($SITE_CONFIGURED) {
-    warn "Site already initialized";
+    warn "site already initialized";
     return 1;
   }
   if ($site_conf) {
-    set_site_config($site_conf)
-      || die "Problem setting config path: $site_conf";
+    if (! -e $site_conf) {
+      warn("site config file does not exist: $site_conf");
+      return 0;
+    }
+    if (! set_site_config($site_conf)) {
+      warn "problem setting site config: $site_conf";
+      return 0;
+    }
   }
   if ($root_dir) {
     if (! -d $root_dir) {
-      warn("The directory $root_dir does not exist");
+      warn "silk root directory does not exist: $root_dir";
       return 0;
     }
     if (! set_data_rootdir($root_dir)) {
-      warn("Illegal root directory");
+      warn("illegal root directory: $root_dir");
       return 0;
     }
   }
-  load_site() || return 0;
+  load_site();
   # These are needed for subprocess calls to silk
-  silk_init_set_envvar($site_conf, SILK_CONFIG_FILE_ENVAR()) if $site_conf;
-  silk_init_set_envvar($root_dir, SILK_DATA_ROOTDIR_ENVAR()) if $root_dir;
-  $HAVE_SITE;
+  silk_init_set_envvar($site_conf, SILK_CONFIG_FILE_ENVAR) if $site_conf;
+  silk_init_set_envvar($root_dir, SILK_DATA_ROOTDIR_ENVAR) if $root_dir;
+  $SITE_CONFIG_OK;
 }
 
 sub load_site {
   return 1 if $SITE_CONFIGURED;
+  $SITE_CONFIG_OK = 0;
   my $site_conf = get_site_config();
-  my $site_res = _site_configure(0);
-  if (!$site_res) {
-    $HAVE_SITE = 1;
+  if (!$site_conf) {
+    warn "no site file defined";
   }
-  elsif ($site_res == -2) {
-    $HAVE_SITE = 0;
-    warn("could not read site file $site_conf") if $site_conf;
-    return 0;
+  elsif (! -e $site_conf) {
+    warn "site file does not exist: $site_conf";
   }
   else {
-    $HAVE_SITE = 0;
-    warn("error parsing site configuration file $site_conf");
-    return 0;
+    my $site_res = _site_configure(0);
+    if (!$site_res) {
+      $SITE_CONFIG_OK = 1;
+    }
+    elsif ($site_res == -2) {
+      warn("could not read site file: $site_conf");
+    }
+    else {
+      warn("error parsing site configuration file: $site_conf");
+    }
   }
-  %SENSORS_BY_ID   = _sensors_by_id();
-  %CLASSES_BY_ID   = _classes_by_id();
-  %FLOWTYPES_BY_ID = _flowtypes_by_id();
-
   $SITE_CONFIGURED = 1;
 }
 
-sub HAVE_SITE_CONFIG { load_site(); $HAVE_SITE }
+sub HAVE_SITE_CONFIG { load_site(); $SITE_CONFIG_OK }
 
 sub HAVE_SITE_CONFIG_SILENT {
   *SAVERR = *STDERR;
@@ -385,6 +396,8 @@ sub repo_iter {
 
 ###
 
+my @ALL;
+
 BEGIN {
   @ALL = qw(
     sensors
@@ -430,9 +443,9 @@ Net::Silk::Site - SiLK site repository configuration
 
 =head1 DESCRIPTION
 
-C<Net::Silk::Site> is the interface to the local repository configuration.
-It can be used to make queries about sensor and class types, as well as
-find flow files present in the repository.
+C<Net::Silk::Site> is the interface to the local repository
+configuration. It can be used to make queries about sensor and class
+types, as well as find flow files present in the repository.
 
 =head1 EXPORTS
 
@@ -455,12 +468,11 @@ successfully loaded.
 
 =item init_site(rootdir => $path, siteconf => $file)
 
-Initializes site configuration to a different root data directory
-and/or site config file in order to override the values determined
-by environment variables or the default. Must be called prior to
-invoking any query functions. Site initialization will be invoked
-automatically, if it hasn't yet been invoked, when any query functions
-are called.
+Initializes site configuration to a different root data directory and/or
+site config file in order to override the values determined by
+environment variables or the default. Must be called prior to invoking
+any query functions. Site initialization will be invoked automatically,
+if it hasn't yet been invoked, when any query functions are called.
 
 =item get_data_rootdir()
 
@@ -525,38 +537,36 @@ classtype id.
 
 =item repo_iter(...)
 
-Return a subroutine reference representing an interator over
-repository files matching the given criteria. The function takes
-the following keyword arguments:
+Return a subroutine reference representing an interator over repository
+files matching the given criteria. The function takes the following
+keyword arguments:
 
 =over
 
 =item start
 
-The starting time of interest, given either as a DateTime object
-or as seconds since the epoch. If I<only> a start time is given
-and it has a resolution to the day, that entire day is queried.
-Otherwise, the given hour is queried.
+The starting time of interest, given either as a DateTime object or as
+seconds since the epoch. If I<only> a start time is given and it has a
+resolution to the day, that entire day is queried. Otherwise, the given
+hour is queried.
 
 =item end
 
-The end time of interest, given either as a L<DateTime> object
-or as seconds since the epoch.
+The end time of interest, given either as a L<DateTime> object or as
+seconds since the epoch.
 
 =item sensors
 
-An array ref containg a list of sensors over which to limit
-the query.
+An array ref containing a list of sensors over which to limit the query.
 
 =item flowtypes
 
-A hash ref containing class/type pairs over which to limit
-the query.
+A hash ref containing class/type pairs over which to limit the query.
 
 =item missing
 
-A flag indicating whether to include files missing from the
-repository in query results.
+A flag indicating whether to include files missing from the repository
+in query results.
 
 =back
 
